'use strict';

/**
 * @license http://www.gnu.org/licenses/gpl.html
 * @link http://www.igalerie.org/
 */

/**
 * Gestion de la scrollbar de la page.
 *
 */
 var page_overflow;
function page_scrollbar_show()
{
	$('body').css(
	{
		'overflow': page_overflow.body,
		'padding': 0
	});
}
function page_scrollbar_hide()
{
	page_overflow =
	{
		body: $('body').css('overflow')
	};
	var width_before = $(window).width();
	$('body').css('overflow', 'hidden');
	$('body').css('padding-right', ($(window).width() - width_before) + 'px');
}



/**
 * Création d'un viewer pour l'affichage d'une image.
 *
 */
function viewer(source)
{
	if (!source)
	{
		return;
	}

	page_scrollbar_hide();

	var resize = function()
	{
		var margin = parseInt($('#viewer').css('paddingLeft')) * 2;
		$('#viewer').css({
			'width': ($(window).width() - margin) + 'px',
			'height': ($(window).height() - margin) + 'px'
		});
	};

	source += source.search(/\?/, source) == -1 ? '?' : '&';
	$('main').append('<div id="viewer"><img src="' + source + Math.random() + '"></div>');

	resize();

	$(window).resize(function()
	{
		if ($('#viewer').is('div'))
		{
			resize();
		}
	});

	$('body').on('click', '#viewer', function()
	{
		$(this).remove();
		page_scrollbar_show();
	});
}



/**
 * Général.
 *
 */
jQuery(function($)
{
	var ajax = false;

	// Ancre.
	var hash = $(location).attr('hash');
	if (hash)
	{
		window.location = hash;
	}

	// Indique que Javascript est activé.
	$('html.nojs').removeClass('nojs').addClass('js');

	// Réinitialisation des formulaires.
	$('form').trigger('reset');

	// Changement de page.
	$('.pages form').submit(function()
	{
		var page = $(this).find('input[name="page"]').val();
		if (page.match(/^\d{1,12}$/) && !page.match(/^0/)
		&& parseInt(page) <= parseInt($(this).find('.count').text()))
		{
			window.location.href = gallery_path + '/'
				+ q_pageless + '/page/' + page + '#top';
		}
		return false;
	});

	// Boutons de sélection de fichier.
	$('input[type="file"]').change(function(e)
	{
		if (e.target.value)
		{
			var filename = e.target.value.replace(/^.*?([^/\\]+)$/, '$1');
			var id = $(this).attr('id');
			$('#' + id + ' + label').text(filename);
		}
	});

	// Réinitialisation des dates.
	$('.date_reset').click(function()
	{
		$(this).parent().find('.date_title').prop('selected', true);
	});

	// Confirmation de suppression.
	$('form').submit(function()
	{
		if ($(this).attr('data-confirm-delete'))
		{
			return confirm(confirm_delete);
		}
	});

	// Déconnexion.
	$('#user_logout a,#link_logout a').click(function()
	{
		$.post(
			gallery_path + '/ajax.php',
			{
				anticsrf: anticsrf,
				section: 'logout',
				id: $(this).attr('data-id') || 0,
				from_admin: 0
			},
			function(r)
			{
				if (typeof r != 'object' || r === null)
				{
					return;
				}
				switch (r.status)
				{
					case 'error' :
						alert('error: ' + r.message);
						break;

					case 'success' :
						window.location = r.redirect;
						break;
				}
			},
			'json'
		);
		return false;
	});

	// Favoris.
	$('#link_favorites a').click(function()
	{
		if (ajax)
		{
			return;
		}
		ajax = true;

		var action = $('#item').hasClass('favorite') ? 'remove' : 'add';

		$.post(gallery_path + '/ajax.php',
		{
			anticsrf: anticsrf,
			section: 'favorites-' + action,
			item_id: item_id
		},
		function(r)
		{
			if (typeof r != 'object' || r === null)
			{
				return;
			}
			switch (r.status)
			{
				case 'error' :
					console.log('error: ' + r.message);
					break;

				case 'success' :
					if (action == 'add')
					{
						$('#item').addClass('favorite');
						$('#link_favorites a').attr('title', favorites_remove_text);
					}
					if (action == 'remove')
					{
						$('#item').removeClass('favorite');
						$('#link_favorites a').attr('title', favorites_add_text);
					}
					$('#item_favorites span:first').text(r.favorites_short);
					if (q_pageless.match(/\/(user-)?favorites(\/\d+){1,2}$/))
					{
						location.reload();
					}
					break;
			}
			setTimeout(function(){ ajax = false; }, 500);
		}, 'json');
	});

	// Menu des langues.
	if ($('#lang_switch').is('div'))
	{
		var langs_box_open = false;
		var close_langs = function()
		{
			$('#lang_switch').css('display', 'none');
			langs_box_open = false;
		};
		$('#footer_lang a').click(function()
		{
			$('#lang_switch').css('display', 'flex');
			langs_box_open = true;
			return false;
		});
		$('#lang_switch').click(function()
		{
			close_langs();
		});
		$('#lang_switch ul').click(function(e)
		{
			e.stopPropagation();
		});
		$('#lang_switch li a').click(function()
		{
			$('main').append('<form id="form_lang" method="post">'
				+ '<input type="hidden" name="lang" value="' + $(this).attr('data-code') + '">'
				+ '<input type="hidden" name="anticsrf" value="' + anticsrf + '">'
				+ '</form>');
			$('#form_lang').submit();
		});
		$(window).keyup(function(e)
		{
			if (langs_box_open && e.keyCode == 27)
			{
				close_langs();
			}
		});
	}

	// Liens "viewer".
	$('body').on('click', '.viewer', function()
	{
		viewer($(this).attr('href'));
		return false;
	});

	// Options de la recherche avancée.
	$('#search_options_link a').click(function()
	{
		var options = $('#search_options');
		if (options.is(':visible'))
		{
			options.hide();
			$('#search_options_link span').html('&#xf067;');
		}
		else
		{
			options.show();
			$('#search_options_link span').html('&#xf068;');
		}
	});
});



/**
 * Boîtes flottantes.
 *
 */
jQuery(function($)
{
	if (!$('*[data-box-name]').length)
	{
		return;
	}

	var box, box_ajax, box_id, box_cat_id, box_page, box_report_timeout;
	var box_close = function(delay, setfocus)
	{
		box_loading_stop();
		clearTimeout(box_report_timeout);
		box.hide('fade', delay, function()
		{
			$('#box_report').remove();
			if (setfocus)
			{
				$('*[data-box-name="' + box_id + '"]').focus();
			}
			box = undefined;
			page_scrollbar_show();
		});
	};

	$('*[data-box-name]').click(function()
	{
		box_id = $(this).attr('data-box-name');
		box = $('#' + box_id);
		if ((box.attr('data-box-large-screen') && $('#small_screen').is(':hidden'))
		|| !box.attr('data-box-large-screen'))
		{
			if (box.is(':visible'))
			{
				box_close(250, true);
			}
			else
			{
				$('.box_outer').hide();
				page_scrollbar_hide();

				box.show('fade', 250);
				box_page = box.find('.box_page:first')
				box_page.find('.focus').focus();

				/* Mot de passe de catégorie. */
				if (box_id == 'box_password')
				{
					box_cat_id = $(this).attr('data-cat-id');
				}
			}
			return false;
		}
	});

	$('*[data-box-close]').click(function()
	{
		box_close(250, true);
	});

	$('*[data-box-page-id]').click(function()
	{
		if (box_page.attr('id') != $(this).attr('data-box-page-id'))
		{
			if (box_ajax)
			{
				return;
			}

			clearTimeout(box_report_timeout);
			$('#box_report').remove();
			box_loading_stop();
		}
		box_page = $('#' + $(this).attr('data-box-page-id'));
		box.find('*[data-box-page-id]').parent().removeClass('current');
		$(this).parent().addClass('current');
		box.find('.box_page').hide();
		box_page.show().find('.focus').focus();
	});

	$(window).keyup(function(e)
	{
		if (box && e.keyCode == 27)
		{
			box_page.find('*[data-box-close]').click();
		}
	});

	/* Requête ajax. */
	function box_ajax_request(params, callback)
	{
		if (box_ajax)
		{
			return;
		}
		box_loading_start();
		box_ajax = $.post(gallery_path + '/ajax.php', params,
			function(r)
			{
				if (r == null)
				{
					box_show_message('error', 'Null.');
					return;
				}
				switch (r.status)
				{
					case 'success' :
						if (r.message)
						{
							box_show_message('success', r.message);
						}
						if (typeof callback == 'function')
						{
							callback(r);
						}
						break;

					case 'error' :
						if (r.message)
						{
							box_show_message('error', r.message);
						}
						if (typeof callback == 'function')
						{
							callback(r);
						}
						break;

					default :
						box_show_message('error', 'Unknown error.');
						break;
				}
			},
		'json')
		.always(function()
		{
			box_ajax = false;
		});
	}

	/* Icône de chargement. */
	function box_loading_start()
	{
		if (!$('#box_loading').length)
		{
			box_page.find('.box_buttons input[type="submit"]').prop('disabled', true);
			box_page.find('.box_buttons').append('<span id="box_loading"></span>');
		}
	}
	function box_loading_stop()
	{
		box_page.find('.box_buttons input[type="submit"]').prop('disabled', false);
		$('#box_loading').remove();
		if (box_ajax)
		{
			box_ajax.abort();
			box_ajax = false;
		}
	}

	/* Messages de rapport. */
	function box_report_remove()
	{
		$('#box_report').animate({'opacity': 0}, 250, function()
		{
			$('#box_report').remove();
			box_loading_stop();
		});
	}
	function box_show_message(type, text)
	{
		$('#box_loading').remove();
		box_page.find('.box_buttons').append((type == 'error')
			? '<div id="box_report"><span class="message_error">' + text + '</span></div>'
			: '<div id="box_report"><span class="message_success">' + text + '</span></div>');
		$('#box_report').css({'display': 'flex', 'opacity': 0});
		$('#box_report').animate({'opacity': 1}, 250);
		if (type == 'success')
		{
			box_report_timeout = setTimeout(box_report_remove, 2000);
		}
	}
	$('body').on('click', '#box_report', function()
	{
		clearTimeout(box_report_timeout);
		box_report_remove();
	});

	/* Édition du fichier : informations. */
	$('body').on('click', '#box_item_infos input[name="save"]', function()
	{
		if ($('#edit_item_title').val().trim() == '')
		{
			return false;
		}

		var after = function(r)
		{
			$('#edit_item_title').val($('#edit_item_title').val().trim());
			$('#edit_item_desc').val($('#edit_item_desc').val().trim());
			if (r.title !== undefined)
			{
				$('#item_title a').html(r.title);
			}
			if (r.description !== undefined)
			{
				if (r.description === null)
				{
					$('#item_description').remove();
				}
				else if ($('#item_description').is('p'))
				{
					$('#item_description').html(r.description);
				}
				else
				{
					$('#item_columns').before(
						'<p id="item_description" class="object_desc">' + r.description + '</p>'
					);
				}
			}
		};

		box_ajax_request({
			section: 'item-edit',
			anticsrf: anticsrf,
			item_id: item_id,
			title: $('#edit_item_title').val(),
			description: $('#edit_item_desc').val()
		}, after);

		return false;
	});

	/* Édition du fichier : tags. */
	$('body').on('click', '#box_item_tags input[name="save"]', function()
	{
		var after = function(r)
		{
			if (r.tags_list !== undefined)
			{
				$('#edit_item_tags').val(r.tags_list.join(', '));
			}
			if (r.tags !== undefined)
			{
				$('#item_tags').remove();
				if (r.tags.length)
				{
					var html = '<div id="item_tags"><h3 class="icon"><span>&#xf02c;</span> '
						+ box_text_tags + '</h3><ul>';
					for (var i in r.tags)
					{
						html += '<li><a href="' + r.tags[i].link + '">'
							+ r.tags[i].name + '</a></li>';
					}
					html += '</ul></div>';
					$('#item_left_inner').append(html);
				}
			}
		};

		box_ajax_request({
			section: 'item-edit',
			anticsrf: anticsrf,
			item_id: item_id,
			tags: $('#edit_item_tags').val()
		}, after);

		return false;
	});

	/* Suppression du fichier. */
	$('body').on('click', '#box_item_delete input[name="delete"]', function()
	{
		if (confirm(box_text_confirm_delete))
		{
			var after = function(r)
			{
				if (r.status == 'success')
				{
					alert(r.message);
					window.location = r.redirect;
				}
			};

			box_ajax_request({
				section: 'item-delete',
				anticsrf: anticsrf,
				item_id: item_id
			}, after);
		}

		return false;
	});

	/* Mot de passe de catégorie. */
	$('body').on('click', '#box_password input[name="submit"]', function()
	{
		if ($('#cat_password').val() == '')
		{
			$('#cat_password').focus();
			return false;
		}

		var after = function(r)
		{
			if (r.status == 'success')
			{
				window.location = r.url;
			}
			else
			{
				$('#cat_password').focus();
				box_report_timeout = setTimeout(box_report_remove, 4000);
			}
		};

		box_ajax_request({
			section: 'cat-password',
			anticsrf: anticsrf,
			password: $('#cat_password').val(),
			remember: $('#cat_remember').prop('checked') ? 1 : 0,
			cat_id: box_cat_id
		}, after);

		return false;
	});
	$('body').on('click', '#box_password *[data-box-close]', function()
	{
		$('#cat_password').val('');

		return false;
	});

	/* Connexion. */
	$('body').on('click', '#box_login input[name="submit"]', function()
	{
		if ($('#login_username').val() == '')
		{
			$('#login_username').focus();
			return false;
		}
		if ($('#login_password').val() == '')
		{
			$('#login_password').focus();
			return false;
		}

		var after = function(r)
		{
			if (r.status == 'success')
			{
				document.location.reload();
			}
			else
			{
				$('#login_username').focus();
				box_report_timeout = setTimeout(box_report_remove, 4000);
			}
		};

		box_ajax_request({
			section: 'login',
			anticsrf: anticsrf,
			login: $('#login_username').val(),
			password: $('#login_password').val(),
			remember: $('#login_remember').prop('checked') ? 1 : 0
		}, after);

		return false;
	});
	$('body').on('click', '#box_login *[data-box-close]', function()
	{
		$('#login_username').val('');
		$('#login_password').val('');

		return false;
	});

	/* Émojis. */
	$('body').on('click', '#box_emoji .box_content .emoji', function()
	{
		var position = $('#message').prop('selectionStart');
		var msg = $('#message').val();
		var before = msg.substring(0, position);
		var after  = msg.substring(position, msg.length);

		$('#message').val(before + $(this).text() + after);
		$('#message').focus().prop('selectionEnd', position + 2);

		box_close(1, false);

		return false;
	});
});



/**
 * Boîtes flottantes avec flèche.
 *
 */
jQuery(function($)
{
	// Gestion de l'affichage des box.
	var box_id, button;
	var box_open = false, menu_open = false;
	var timeout_box = [];
	var browse_resize = function()
	{
		if (box_id != 'browse')
		{
			return;
		}
		var available_height = $(window).height();
		var top = Math.round($('#menu_gallery')[0].getBoundingClientRect().bottom);
		var max_height = available_height - top - 100;
		max_height = max_height > 600 ? 600 : max_height;
		$('#browse ul').css('maxHeight', max_height + 'px');
	};
	var clear_box = function()
	{
		if (box_open)
		{
			clearTimeout(timeout_box[box_id]);
		}
	};
	var close_box = function()
	{
		if ($('#small_screen').is(':hidden')
		 && $('#' + box_id).hasClass('box_arrow_small_screen'))
		{
			return;
		}
		$('#' + box_id).fadeOut(anim_speed);
		if (!$('.box_outer').is(':visible'))
		{
			$('.box_arrow_link[data-box="' + box_id + '"]').focus();
		}

		box_open = false;
	};
	var hide_box = function()
	{
		if (!box_open || $('#' + box_id + ' input:first').is(':focus'))
		{
			return;
		}
		clear_box();
		timeout_box[box_id] = setTimeout(function(){ close_box(); }, 500);
	};
	var position_box = function()
	{
		if ($('.box_arrow_link[data-box="' + box_id + '"]').hasClass('box_arrow_custom'))
		{
			return;
		}

		var margin = 15;
		var box_width = $('#' + box_id).outerWidth();
		var top = button.offset().top + button.outerHeight() + 2;
		var left = (button.offset().left + (button.outerWidth() / 2)) - (box_width / 2);
		var previous_left = left;
		var arrow_width = $('#' + box_id + ' .arrow_top').outerWidth();
		var arrow_left = ((box_width / 2) - (arrow_width / 2));
		var gallery_left = $('#gallery').offset().left + margin;
		var gallery_right = gallery_left + $('#gallery').outerWidth() - (margin * 2);

		// Correction de la position si nécessaire.
		if (left < gallery_left)
		{
			left = gallery_left;
		}
		else if (left + box_width > gallery_right)
		{
			left = gallery_right - box_width;
		}
		arrow_left -= left - previous_left;

		$('#' + box_id + ' div[class^="arrow"]').css({left: arrow_left + 'px'});
		$('#' + box_id).css({
			top: (top + 17) + 'px',
			left: left + 'px',
			zIndex: 100
		});
	};
	$('.box_arrow_link').click(function()
	{
		box_open = false;
		box_id = $(this).attr('data-box');
		button = $(this);
		if (menu_open && box_id == 'browse' && !$('#small_screen').is(':hidden'))
		{
			return true;
		}
		for (var bi in timeout_box)
		{
			clearTimeout(timeout_box[bi]);
		}
		if ($('#' + box_id).is(':hidden'))
		{
			// Fermeture de toutes les boîtes.
			$('.box_arrow').hide();

			// Si le menu est ouvert, on le ferme.
			if (!$('#menu').is(':hidden'))
			{
				close_menu();
			}

			if (!$(this).hasClass('box_arrow_custom'))
			{
				// Flèche.
				if (!$('#' + box_id + ' .arrow_top').is('div'))
				{
					$('#' + box_id).prepend(
						'<div class="arrow_top_border"></div><div class="arrow_top"></div>'
					);
				}

				// Positionnement de la boîte.
				position_box();
			}

			// Ouverture de la boîte.
			$('#' + box_id).fadeIn(anim_speed, function()
			{
				$('#' + box_id + ' input:first').focus();
				browse_resize();
				box_open = true;
			});
		}
		else
		{
			close_box();
		}

		if ($('#' + box_id).length)
		{
			return false;
		}
	});
	$('.box_arrow,.box_arrow_link')
		.bind('mouseenter', function(){ clear_box(); })
		.bind('mouseleave', function(){ hide_box(); });
	$('.box_arrow').click(function(e)
	{
		if (box_open)
		{
			e.stopPropagation();
		}
	});
	$(window).click(function(e)
	{
		if (box_open)
		{
			close_box();
		}
	});
	$(window).keyup(function(e)
	{
		if (box_open && e.keyCode == 27)
		{
			close_box();
		}
	});
	$(window).resize(function()
	{
		if (!box_open)
		{
			return;
		}
		if (!$('#small_screen').is(':hidden'))
		{
			$('#' + box_id).hide();
			return;
		}
		position_box();
		browse_resize();
	});

	// Recherche dans la Liste des catégories.
	if ($('#browse').is('div'))
	{
		var escape = function(str)
		{
			str = str.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, "\\$&");
			str = str.replace(/\s+/g, '\\s+')
			return str;
		};
		$('#browse_search input').val('');
		$('#browse_search').on('input', function(e)
		{
			var val = $(this).children('input').val();
			var regexp = new RegExp(escape(val), 'i');
			$('#browse li').hide();
			$('#browse li').each(function()
			{
				if (regexp.test($(this).find('span').text()))
				{
					$(this).show();
				}
			});
		});
	}

	var anim_speed = 150;

	// Gestion de l'affichage du menu principal.
	var close_menu = function()
	{
		if ($('#small_screen').is(':hidden'))
		{
			return;
		}
		menu_open = false;
		$('#menu').slideUp(anim_speed, function()
		{
			$('#menu_link').html('&#xe966;');
			$('main').removeClass('dark');
		});
		
	};
	$('#menu_link').click(function(e)
	{
		menu_open = false;
		if ($('#menu').is(':hidden'))
		{
			$('.box_arrow').hide();
			box_open = false;
			$('#menu').slideDown(anim_speed, function()
			{
				$('#menu_link').html('&#xe916;');
				$('main').addClass('dark');
				menu_open = true;
			});
		}
		else
		{
			close_menu();
		}
		e.stopPropagation();
	});
	$('#menu').click(function(e)
	{
		if (menu_open)
		{
			e.stopPropagation();
		}
	});
	$(window).keyup(function(e)
	{
		if (!menu_open || $('#small_screen').is(':hidden'))
		{
			return;
		}
		if (e.keyCode == 27)
		{
			close_menu();
		}
	});
	$(window).click(function()
	{
		if (!menu_open || $('#small_screen').is(':hidden'))
		{
			return;
		}
		close_menu();
	});
});



/**
 * Carte du monde.
 *
 */
jQuery(function($)
{
	if (!$('#worldmap').length)
	{
		return;
	}

	var lat = $('#worldmap').attr('data-lat');
	var lng = $('#worldmap').attr('data-long');

	// Initialisation de la carte.
	var map = L.map('worldmap',
	{
		center: [lat, lng],
		zoom: $('#worldmap').attr('data-zoom')
	});
	L.tileLayer('https://{s}.tile.openstreetmap.fr/osmfr/{z}/{x}/{y}.png',
	{
		attribution: '<a href="//osm.org/copyright">OpenStreetMap</a>'
	}).addTo(map);

	// Marqueurs.
	var marker_cat = L.icon(
	{
		iconUrl: gallery_path + '/images/markers/marker-category.png',
		iconSize: [20, 34],
		iconAnchor: [10, 34],
		popupAnchor: [0, -39],
		shadowUrl: gallery_path + '/images/markers/marker-shadow.png',
		shadowSize: [54, 34],
		shadowAnchor: [27, 34]
	});
	var marker_item = L.icon(
	{
		iconUrl: gallery_path + '/images/markers/marker-item.png',
		iconSize: [20, 34],
		iconAnchor: [10, 34],
		popupAnchor: [0, -39],
		shadowUrl: gallery_path + '/images/markers/marker-shadow.png',
		shadowSize: [54, 34],
		shadowAnchor: [27, 34]
	});

	// Page des fichiers.
	if ($('#item_geolocation').length)
	{
		var marker = L.marker([lat, lng], {icon: marker_item}).addTo(map);
	}

	// Page "carte du monde".
	else
	{
		for (var i in markers)
		{
			// Fichiers.
			var items_count = Object.keys(markers[i].items).length;
			if (items_count)
			{
				var marker = L.marker(
					[markers[i].lat, markers[i].lng], {icon: marker_item}
				).addTo(map);
				var html_thumbs = '';
				var html_pagination = '';
				if (items_count > 1)
				{
					html_pagination = thumbs_pagination.replace(/\{count\}/g, items_count);
				}
				var num = 1;
				for (var n in markers[i].items)
				{
					html_thumbs += (markers[i].items[n].type == 'video'
						? thumbs_video : thumbs_image)
						.replace(/\{num\}/g, num++)
						.replace(/\{id\}/g, markers[i].items[n].id)
						.replace(/\{duration\}/g, markers[i].items[n].duration)
						.replace(/\{link\}/g, markers[i].items[n].link)
						.replace(/\{place\}/g, markers[i].items[n].place)
						.replace(/\{source\}/g, markers[i].items[n].source)
						.replace(/\{title\}/g, markers[i].items[n].title);
				}
				marker.bindPopup(thumbs_items
					.replace(/\{pagination\}/g, html_pagination)
					.replace(/\{thumbs\}/g, html_thumbs)
				);
			}

			// Catégories.
			var cat_count = Object.keys(markers[i].categories).length;
			if (cat_count)
			{
				var marker = L.marker(
					[markers[i].lat, markers[i].lng], {icon: marker_cat}
				).addTo(map);
				var html_thumbs = '';
				var html_pagination = '';
				if (cat_count > 1)
				{
					html_pagination = thumbs_pagination.replace(/\{count\}/g, cat_count);
				}
				var num = 1;
				for (var n in markers[i].categories)
				{
					html_thumbs += thumbs_image
						.replace(/\{num\}/g, num++)
						.replace(/\{id\}/g, markers[i].categories[n].id)
						.replace(/\{link\}/g, markers[i].categories[n].link)
						.replace(/\{source\}/g, markers[i].categories[n].source)
						.replace(/\{title\}/g, markers[i].categories[n].title);
				}
				var html = thumbs_categories
					.replace(/\{pagination\}/g, html_pagination)
					.replace(/\{thumbs\}/g, html_thumbs);
				marker.bindPopup(html);
			}
		}
		$('body').on('click', '#thumbs_pagination a', function()
		{
			var button = $(this).attr('id').replace('thumbs_pagination_', '');
			var text = $('#thumbs_pagination span').text().split('/');
			var current = parseInt(text[0]);
			var count = parseInt(text[1]);
			var item = current + (button == 'prev' ? -1 : 1);

			$('#popup_' + current).hide();
			$('#popup_' + item).show();

			$('#thumbs_pagination_' + (button == 'prev' ? 'next' : 'prev'))
				.css('visibility', 'visible');
			if ((button == 'prev' && item == 1) || (button == 'next' && item == count))
			{
				$('#thumbs_pagination_' + button).css('visibility', 'hidden');
			}

			$('#thumbs_pagination span').text(item + '/' + count);
		});
	}
});



/**
 * Votes.
 *
 */
jQuery(function($)
{
	if (!$('#item_user_note').length)
	{
		return;
	}

	var empty = $('#item_rating').attr('data-rating-empty');
	var half = $('#item_rating').attr('data-rating-half');
	var full = $('#item_rating').attr('data-rating-full');
	var current_rating_text = [];
	var click = false;

	function current()
	{
		current_rating_text = [];
		$('#item_user_note .rating').each(function()
		{
			current_rating_text.push($(this).text());
		});
	}

	function update(r)
	{
		for (var i = 0; i <= r.rating_array.length; i++)
		{
			$('#item_note span[data-rating="' + (i + 1) + '"]').text(
				r.rating_array[i] == 1 ? full : (r.rating_array[i] == 0 ? empty : half)
			);
		}
		$('#item_rating_votes').text(r.votes_short);
		$('#item_note_formated').text(r.rating);
		current();
	}

	function vote_click()
	{
		if (click)
		{
			return;
		}
		click = true;
		$.post(gallery_path + '/ajax.php', {
			section: 'vote-add',
			anticsrf: anticsrf,
			rating: $(this).attr('data-rating'),
			item_id: item_id
		},
		function(r)
		{
			if (r == null)
			{
				return;
			}
			switch (r.status)
			{
				case 'success' :
					$('#item_user_note_delete').show();

					update(r);

					// Si on se trouve dans la section des fichiers les mieux
					// notés, on recharge la page car le fichier ne se trouve
					// plus forcément à la même position dans cette section,
					// ce qui ne chargerait pas la bonne image au lancement
					// du diaporama si on ne le faisait pas.
					if (q_pageless.match(/\/votes\/\d+$/))
					{
						location.reload();
					}
					break;

				case 'error' :
					alert('error: ' + r.message);
					break;
			}
			click = false;
		}, 'json');
	}

	function vote_delete()
	{
		if (click)
		{
			return;
		}
		click = true;
		$.post(gallery_path + '/ajax.php', {
			section: 'vote-remove',
			anticsrf: anticsrf,
			item_id: item_id
		},
		function(r)
		{
			if (r == null)
			{
				return;
			}
			switch (r.status)
			{
				case 'success' :
					$('#item_user_note .rating').text(empty);
					$('#item_user_note_delete').hide();

					update(r);

					if (q_pageless.match(/\/votes\/\d+$/))
					{
						location.reload();
					}
					break;

				case 'error' :
					alert('error: ' + r.message);
					break;
			}
			click = false;
		}, 'json');
	}

	function vote_in()
	{
		if (!click)
		{
			var rating = $(this).attr('data-rating');
			var n = 1;
			$('#item_user_note .rating').each(function()
			{
				$(this).text(n > rating ? empty : full);
				n++;
			});
		}
	}

	function vote_out()
	{
		if (!click)
		{
			var i = 0;
			$('#item_user_note .rating').each(function()
			{
				$(this).text(current_rating_text[i]);
				i++;
			});
		}
	}

	current();
	$('#item_user_note .rating').on('mouseenter', vote_in).on('click', vote_click);
	$('#item_user_note > span').on('mouseleave', vote_out);
	$('#item_user_note_delete').on('click', vote_delete);
});



/**
 * Ajout de fichiers.
 *
 */
jQuery(function($)
{
	if ($('body').attr('id') != 'section_user_upload' || !$('#upload').is('div'))
	{
		return;
	}

	// Envoi de fichiers.
	var upload = new Upload('upload_', upload_options);

	// Gestion des listes d'albums.
	var select_cat_change = function()
	{
		$('#upload_categories select').change(function()
		{
			var id = parseInt($(this).children('option:selected').val());
			var key = albums_list.k.indexOf(id);

			// Supprime toutes les listes enfants à partir de la liste courante.
			var i = parseInt($(this).attr('id').replace(/upload_categories_/, ''));
			var n = i + 1;
			while ($('#upload_categories_' + n).is('select'))
			{
				$('#upload_categories_' + n).remove();
				$('#upload_sep_' + n).remove();
				n++;
			}

			// Crée la nouvelle liste enfant si c'est une catégorie.
			if (albums_list.k.includes(id) && albums_list.v[key].type == 1)
			{
				select_cat_create(id, i + 1);
			}

			// Album sélectionné.
			var n = 1;
			while ($('#upload_categories_' + n).is('select'))
			{
				n++;
			}
			n--;
			var id = $('#upload_categories_' + n + ' option:selected').val();
			if (key > 0 && albums_list.v[key].type == 0)
			{
				upload.options.ajaxData.album_id = id;
				var text = albums_list.v[key].title;
				var parent_id = albums_list.v[key].parent;
				var parent_key = albums_list.k.indexOf(parent_id);
				while (albums_list.k.includes(parent_id) && parent_id > 1)
				{
					text = albums_list.v[parent_key].title + cat_separator + text;
					parent_id = albums_list.v[parent_key].parent;
					parent_key = albums_list.k.indexOf(parent_id);
				}
				$('#select_path').removeClass().addClass('message_success').html(text);
			}
			else
			{
				upload.options.ajaxData.album_id = null;
				$('#select_path').removeClass().addClass('message_info')
					.html(upload_options.text.noAlbum);
			}
			$('input[name="cat_id"]').val(upload.options.ajaxData.album_id);
		});
	};
	var select_cat_create = function(cat_id, i)
	{
		var list = '<select id="upload_categories_' + i + '"><option>['
			+ upload_options.text.selectAlbum + ']</option>';
		var sep = (i > 1) ? '<span id="upload_sep_' + i + '">' + cat_separator + '</span>' : '';
		for (var key in albums_list.k)
		{
			if (albums_list.v[key].parent == cat_id)
			{
				list += '<option value="' + albums_list.k[key] + '">'
					+ albums_list.v[key].title + '</option>';
			}
		}
		list += '</select>';
		$('#upload_categories').append(sep + list);
		select_cat_change();
	};

	// Initialisation.
	select_cat_create(1, 1);

	// Album auto-sélectionné.
	var autoselect = upload_options.ajaxData.album_id;
	if (albums_list.k.includes(autoselect))
	{
		var key = albums_list.k.indexOf(autoselect);
		var parent_id = albums_list.v[key].parent;
		var parents = [];
		while (albums_list.k.includes(parent_id) && parent_id > 1)
		{
			parents.push(parent_id);
			key = albums_list.k.indexOf(parent_id);
			parent_id = albums_list.v[key].parent;
		}
		var n = 2;
		for (var i = parents.length - 1; i > -1; i--)
		{
			select_cat_create(parents[i], n);
			$('#upload_categories_' + (n - 1) + ' option[value="' + parents[i] + '"]')
				.prop('selected', true);
			n++;
		}
		$('#upload_categories_' + (n-1) + ' option[value="' + autoselect + '"]')
			.prop('selected', true);
		$('#upload_categories_' + (n-1)).change();
	}
});



/**
 * Gestion du thème.
 *
 */
jQuery(function($)
{
	if (!$('#theme_options').length)
	{
		return;
	}

	var css_data = $('#css_custom').html();
	var options_left = '-360px';

	function css_replace(regex_search, regex_replace, part)
	{
		if (part)
		{
			var regexp = (part == 'css_code')
				? new RegExp('^([\\s\\S]*/\\*<' + part
					+ '>\\*/)([\\s\\S]*?)(/\\*</' + part
					+ '>\\*\/[\\s\\S]*)$', 'gim')
				: new RegExp('^([\\s\\S]*/\\*<' + part
					+ '>\\*/(?:/\\*)?)([\\s\\S]*?)((?:\\*/)?/\\*</' + part
					+ '>\\*\/[\\s\\S]*)$', 'gim');
			var css_part = css_data.replace(regexp, '$2');
			css_part = css_part.replace(new RegExp(regex_search, 'gim'), regex_replace);
			css_data = css_data.replace(regexp, '$1' + css_part + '$3');
		}
		else
		{
			css_data = css_data.replace(new RegExp(regex_search, 'gim'), regex_replace);
		}

		$('#css_custom').text(css_data);
	}

	function css_status(part, status)
	{
		var regexp = new RegExp(
			'^([\\s\\S]*)(/\\*<' + part + '>\\*/[\\s\\S]*/\\*</' + part + '>\\*\/)([\\s\\S]*)$',
			'gim'
		);
		var css_part = css_data.replace(regexp, '$2');
		var start = RegExp('(/\\*<' + part + '>\\*/)/\\*', 'gim');

		if (status)
		{
			if (start.test(css_part))
			{
				css_part = css_part
					.replace(start, '$1')
					.replace(RegExp('\\*/(/\\*</' + part + '>\\*/)', 'gim'), '$1');
			}
		}
		else
		{
			if (!start.test(css_part))
			{
				css_part = css_part
					.replace(RegExp('(/\\*<' + part + '>\\*/)', 'gim'), '$1/*')
					.replace(RegExp('(/\\*</' + part + '>\\*/)', 'gim'), '*/$1');
			}
		}

		css_data = css_data.replace(regexp, '$1' + css_part + '$3');

		$('#css_custom').text(css_data);
	}

	// Ouverture/fermeture du panneau latéral.
	$('#theme_options_icon a').click(function()
	{
		if ($('#theme_options').css('left') == options_left)
		{
			$('#theme_options').animate({left: '0'}, 250);
		}
		else
		{
			$('#theme_options').animate({left: options_left}, 250);
		}
	});

	// Style.
	if (theme_params_json['style'] == 'clear')
	{
		$('#theme_style_clear').prop('checked', true);
		$('#theme_style_dark').prop('checked', false);
	}
	else
	{
		$('#theme_style_clear').prop('checked', false);
		$('#theme_style_dark').prop('checked', true);
	}

	$('body').on('change', 'input[name="theme_style"]', function()
	{
		if ($(this).val() == 'dark')
		{
			css_status('dark', 1);
			theme_params_json['style'] = 'dark';
			change_color(theme_params_json['color']['dark']);
		}
		else
		{
			css_status('dark', 0);
			theme_params_json['style'] = 'clear';
			change_color(theme_params_json['color']['clear']);
		}

		change_textures();
		change_banner_type();
		change_banner_height();
		change_background_type();
		change_form_buttons();
		change_css_code();

		change_css_texture('banner',
			theme_params_json['banner'][$(this).val()]['texture']);
		change_css_texture('background',
			theme_params_json['background'][$(this).val()]['texture']);
	});

	// Couleurs.
	var color_init = theme_params_json['color'][theme_params_json['style']];

	var color_picker = new iro.ColorPicker('#theme_color_picker',
	{
		color: '#' + color_init,
		width: 300
	});

	var color_picker_change = function()
	{
		$('#theme_color_code').val(color_picker.color.hexString);

		var rgb = 'rgb('
			+ color_picker.color.rgb.r + ', '
			+ color_picker.color.rgb.g + ', '
			+ color_picker.color.rgb.b + ')';
		css_replace('rgb\\([\\d\\s,]+\\)', rgb);

		var color = color_picker.color.hexString.replace('#', '');
		theme_params_json['color'][theme_params_json['style']] = color;

		change_banner_textures_color(color);
	};

	color_picker.on('color:change', color_picker_change);

	$('#theme_color_code').val('#' + color_init);

	$('#theme_palette span').each(function()
	{
		$(this).css('background', '#' + $(this).attr('data-code'));
	});

	$('body').on('click', '#theme_palette span', function()
	{
		if (!css_data)
		{
			return;
		}

		var color = $(this).attr('data-code');
		color_picker.color.hexString = '#' + color;

		css_replace('rgb\\([\\d\\s,]+\\)', hex_rgb(color));

		$('#theme_palette span').removeClass('current');
		$(this).addClass('current');

		change_banner_textures_color(color);

		theme_params_json['color'][theme_params_json['style']] = $(this).attr('data-code');
	});

	$('#theme_color_code').on('input', function()
	{
		var color = $(this).val();
		var regexp = RegExp('^#[a-f0-9]{6}$', 'i');
		if (regexp.test(color))
		{
			color_picker.color.hexString = color;
			color_picker_change();
		}
	});

	$('body').on('change', 'input[name="theme_color_type"]', function()
	{
		if ($(this).val() == 'palette')
		{
			$('#theme_palette').show();
			$('#theme_custom_color').hide();

			var color = theme_params_json['color'][theme_params_json['style']];
			$('#theme_palette span').removeClass('current');
			$('#theme_palette span[data-code="' + color + '"]').addClass('current');
		}
		else
		{
			$('#theme_palette').hide();
			$('#theme_custom_color').show();
		}
	});

	change_color(color_init);

	function change_color(color)
	{
		if ($('#theme_palette span[data-code="' + color + '"]').length)
		{
			$('#theme_color_type_palette').prop('checked', true);
			$('#theme_color_type_custom').prop('checked', false);
			$('#theme_palette').show();
			$('#theme_custom_color').hide();
			$('#theme_palette span[data-code="' + color + '"]').click();
		}
		else
		{
			$('#theme_color_type_palette').prop('checked', false);
			$('#theme_color_type_custom').prop('checked', true);
			$('#theme_palette').hide();
			$('#theme_custom_color').show();
			color_picker.color.hexString = '#' + color;
		}
	}

	function hex_rgb(hex)
	{
		var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
		return result
			? 'rgb('
				+ parseInt(result[1], 16) + ', '
				+ parseInt(result[2], 16) + ', '
				+ parseInt(result[3], 16) +
			  ')'
			: 'rgb(51, 51, 51)';
	}

	// Textures.
	change_textures();

	function change_css_texture(type, file)
	{
		var style = theme_params_json['style'];
		var color = (theme_textures_json[type][style][file] == ''
			? '#' + theme_params_json['color'][theme_params_json['style']]
			: theme_textures_json[type][style][file]);
		var fixed = (type == 'background' && theme_params_json[type][style]['fixed'] == 1)
			? 'fixed'
			: '';
		css_replace(
			'\\{background:.+\\}',
			'{background:' + fixed + ' ' + color + ' url(' + theme_textures_dir + file + ')}',
			type + '_texture'
		);
	}

	function change_textures()
	{
		textures_list('banner');
		textures_list('background');
	}

	function textures_list(type, next_page)
	{
		var style = theme_params_json['style'];
		var items_count = Object.keys(theme_textures_json[type][style]).length;
		var nb_per_page = 3;
		var pages_count = Math.ceil(items_count / nb_per_page);
		var current_page = 1;
		var current_item = 0;
		var e = 'div[data-type="' + type + '"]';
		var selected = theme_params_json[type][style]['texture'];

		var i = 1;
		for (var file in theme_textures_json[type][style])
		{
			if (file == selected)
			{
				current_item = i;
				current_page = Math.ceil(i / nb_per_page);
				break;
			}
			i++;
		}

		if (next_page !== undefined)
		{
			current_page = parseInt($(e).attr('data-page')) + next_page;
		}

		var html = '';
		var end = current_page * nb_per_page;
		var start = 1 + end - nb_per_page;

		var i = 1;
		for (var file in theme_textures_json[type][style])
		{
			if (i >= start && i <= end)
			{
				html += '<div'
					+ ' data-texture="' + file + '"'
					+ (i == current_item ? ' class="selected"' : '')
					+ ' style="background:'
					+ (theme_textures_json[type][style][file] == ''
						? '#' + theme_params_json['color'][theme_params_json['style']]
						: theme_textures_json[type][style][file])
					+ ' url(' + theme_textures_dir + file + ')"></div>';
			}
			i++;
		}

		$(e + ' .theme_textures_prev,' + e + ' .theme_textures_next').addClass('disabled');
		if (current_page > 1)
		{
			$(e + ' .theme_textures_prev').removeClass('disabled');
		}
		if (current_page != pages_count)
		{
			$(e + ' .theme_textures_next').removeClass('disabled');
		}

		$(e + ' .theme_textures_images').html(html);
		$(e).attr('data-page', current_page);
	}

	$('body').on('click', '.theme_textures_prev:not(.disabled)', function()
	{
		textures_list($(this).parent().attr('data-type'), -1);
	});

	$('body').on('click', '.theme_textures_next:not(.disabled)', function()
	{
		textures_list($(this).parent().attr('data-type'), 1);
	});

	$('body').on('click', '.theme_textures_images > div', function()
	{
		var file = $(this).attr('data-texture');
		var type = $(this).parents('.theme_textures').attr('data-type');
		var current = theme_params_json[type][theme_params_json['style']]['texture'];

		if (file != current)
		{
			change_css_texture(type, file);

			theme_params_json[type][theme_params_json['style']]['texture'] = file;
			$(this).parent().find('div').removeClass('selected');
			$(this).addClass('selected');
		}
	});

	// Bannière.
	change_banner_type();
	change_banner_height();

	$('#theme_banner_height').change(function()
	{
		var e = $(this).find('option:selected');
		$(this).find('option').attr('selected', false);
		e.attr('selected', true);

		theme_params_json['banner'][theme_params_json['style']]['height'] = e.val();
		css_replace('height:\\d+px', 'height:' + e.val(), 'banner_height');
	});

	$('#theme_banner_filename').change(function()
	{
		var e = $(this).find('option:selected');
		$(this).find('option').attr('selected', false);
		e.attr('selected', true);

		theme_params_json['banner'][theme_params_json['style']]['file'] = e.val();
		css_replace('url\\(.*?\\)', 'url(' + theme_banners_dir + e.val() + ')', 'banner_file');
	});

	function change_banner_height()
	{
		var height = theme_params_json['banner'][theme_params_json['style']]['height'];
		css_replace('height:\\d+px', 'height:' + height, 'banner_height');

		$('#theme_banner_height option').attr('selected', false);
		$('#theme_banner_height option[value="' + height + '"]')
			.attr('selected', true)
			.prop('selected', true);
	}

	function change_banner_file()
	{
		var file = theme_params_json['banner'][theme_params_json['style']]['file'];
		var selector;

		$('#theme_banner_filename option').attr('selected', false);
		if ($('#theme_banner_filename option[value="' + file + '"]').length)
		{
			selector = '#theme_banner_filename option[value="' + file + '"]';
		}
		else
		{
			selector = '#theme_banner_filename option:first-child';
			file = $(selector).val();
			theme_params_json['banner'][theme_params_json['style']]['file'] = file;
		}

		css_replace('url\\(.*?\\)', 'url(' + theme_banners_dir + file + ')', 'banner_file');
		$(selector).attr('selected', true).prop('selected', true);
	}

	function change_banner_type()
	{
		$('#theme_banner_type_none').prop('checked', false);
		$('#theme_banner_type_texture').prop('checked', false);
		$('#theme_banner_type_file').prop('checked', false);

		$('#theme_banner_file').hide();
		$('#theme_banner_texture').hide();

		$('#theme_banner_height').parent().show();

		switch (theme_params_json['banner'][theme_params_json['style']]['type'])
		{
			case 'file' :
				$('#theme_banner_type_file').prop('checked', true);

				$('#theme_banner_file').show();

				css_status('banner_file', 1);
				css_status('banner_texture', 0);
				$('header').addClass('banner');

				change_banner_file();
				break;

			case 'none' :
				$('#theme_banner_type_none').prop('checked', true);

				css_status('banner_file', 0);
				css_status('banner_texture', 0);
				$('header').removeClass('banner');

				$('#theme_banner_height').parent().hide();
				break;

			case 'texture' :
				$('#theme_banner_type_texture').prop('checked', true);

				$('#theme_banner_texture').show();

				css_status('banner_file', 0);
				css_status('banner_texture', 1);
				$('header').addClass('banner');
				break;
		}
	}

	function change_banner_textures_color(color)
	{
		if (theme_params_json['style'] == 'clear')
		{
			// Changement de couleur de la liste des textures.
			$('div[data-type="banner"] .theme_textures_images > div').each(function()
			{
				$(this).attr('style', $(this).attr('style')
					.replace(new RegExp(':.+?\\s', 'gim'), ':#' + color + ' '));
			});

			// Changement de couleur de la bannière.
			css_replace(':\\s*#.+?\\s', ':#' + color + ' ', 'banner_texture');
		}
	}

	$('body').on('change', 'input[name="theme_banner_type"]', function()
	{
		theme_params_json['banner'][theme_params_json['style']]['type'] = $(this).val();

		change_banner_type();
	});

	// Fond.
	change_background_type();

	function change_background_type()
	{
		$('#theme_background_type_none').prop('checked', false);
		$('#theme_background_type_border').prop('checked', false);
		$('#theme_background_type_texture').prop('checked', false);
		$('#theme_background_texture').hide();
		$('#theme_background_fixed').parent().hide();

		switch (theme_params_json['background'][theme_params_json['style']]['type'])
		{
			case 'none' :
				$('#theme_background_type_none').prop('checked', true);
				css_status('background_texture', 0);
				$('body').removeClass('bg');
				break;

			case 'border' :
				$('#theme_background_type_border').prop('checked', true);
				css_status('background_texture', 0);
				$('body').addClass('bg');
				break;

			case 'texture' :
				$('#theme_background_type_texture').prop('checked', true);
				$('#theme_background_texture').show();
				css_status('background_texture', 1);
				$('body').addClass('bg');
				$('#theme_background_fixed').parent().show();
				break;
		}

		$('#theme_background_fixed').prop('checked',
			theme_params_json['background'][theme_params_json['style']]['fixed'] == 1);
	}

	$('body').on('change', 'input[name="theme_background_type"]', function()
	{
		theme_params_json['background'][theme_params_json['style']]['type'] = $(this).val();

		change_background_type();
	});

	$('#theme_background_fixed').change(function()
	{
		theme_params_json['background'][theme_params_json['style']]['fixed']
			= $(this).prop('checked') ? 1 : 0;
		change_css_texture('background',
			theme_params_json['background'][theme_params_json['style']]['texture']);
	});

	// Boutons de formulaires.
	change_form_buttons();

	function change_form_buttons()
	{
		var buttons_style = theme_params_json['buttons'][theme_params_json['style']]['style'];
		$('#theme_form_buttons_style_1').prop('checked', false);
		$('#theme_form_buttons_style_2').prop('checked', false);
		$('#theme_form_buttons_style_' + buttons_style).prop('checked', true);
		css_status('buttons_style_2_' + theme_params_json['style'], buttons_style == 2 ? 1 : 0);
		css_status('buttons_style_2_'
			+ (theme_params_json['style'] == 'dark' ? 'clear' : 'dark'), 0);
	}

	$('input[name="theme_form_buttons_style"]').change(function()
	{
		theme_params_json['buttons'][theme_params_json['style']]['style'] = $(this).val();
		change_form_buttons();
	});

	// Code CSS personnalisé.
	change_css_code(true);

	function change_css_code(init)
	{
		var css = theme_params_json['css'][theme_params_json['style']];
		$('#theme_css_code').val(css);

		if (!init)
		{
			var color = theme_params_json['color'][theme_params_json['style']];
			css_replace('^[\\s\\S]*$', css.replace(/#color/g, hex_rgb(color)), 'css_code');
		}
	}

	$('#theme_css_code').on('input', function()
	{
		theme_params_json['css'][theme_params_json['style']] = $('#theme_css_code').val();
		change_css_code();
	});

	// Vignettes.
	change_thumbs_layout();

	function change_thumbs_layout()
	{
		var thumbs_layout = theme_params_json['thumbs_items']['layout'];
		$('#theme_thumbs_items_type_standard').prop('checked', false);
		$('#theme_thumbs_items_type_square').prop('checked', false);
		$('#theme_thumbs_items_type_' + thumbs_layout).prop('checked', true);
	}

	$('input[name="theme_thumbs_items_type"]').change(function()
	{
		var layout = $(this).val();
		theme_params_json['thumbs_items']['layout'] = layout;
		change_thumbs_layout();

		if ($('#thumbs_items').length)
		{
			var items_id = [];
			$('#thumbs_items dl').each(function()
			{
				items_id.push(parseInt($(this).attr('data-id')));
			});

			$('#theme_thumbs_items_type').prop('disabled', true);
			$.post(
				gallery_path + '/ajax.php',
				{
					anticsrf: anticsrf,
					section: 'thumbs-items-source',
					items_id: items_id,
					size: layout == 'square' ? '161x161' : '151'
				},
				function(r)
				{
					if (typeof r != 'object' || r === null)
					{
						return;
					}
					switch (r.status)
					{
						case 'error' :
							alert('error: ' + r.message);
							break;

						case 'success' :
							$('#thumbs_items').attr('class', layout);
							for (var id in r.thumbs_source)
							{
								$('#thumbs_items dl[data-id="' + id + '"] img')
									.attr('src', r.thumbs_source[id]);
							}
							break;
					}
					$('#theme_thumbs_items_type').prop('disabled', false);
				},
				'json'
			);

		}
	});

	// Options d'affichage.
	for (var name in theme_params_json['display'])
	{
		$('#theme_display_' + name).prop('checked', theme_params_json['display'][name] == '1');
		$('#theme_display_' + name).click(function()
		{
			var name = $(this).attr('id').replace('theme_display_', '');
			theme_params_json['display'][name] = $(this).prop('checked') ? '1' : '0';
			if ($(this).prop('checked'))
			{
				$('*[data-option-display="' + name + '"]').show();
				if (name == 'menu')
				{
					$('#menu_link').css({'margin-top': '0', 'position': 'relative'});
				}
			}
			else
			{
				$('*[data-option-display="' + name + '"]').hide();
				if (name == 'menu')
				{
					$('#menu_link').css({'margin-top': '-9999px', 'position': 'absolute'});
				}
			}
		});
	}

	// Enregistrement des paramètres.
	var theme_report_timeout;
	var theme_report_hide = function()
	{
		$('div[id^="theme_report"]').css({'display': 'none'});
		$('#theme_options input[type="submit"]').prop('disabled', false).blur();
	};
	$('#theme_options form').submit(function()
	{
		var message = function(type, message)
		{
			$('#theme_report_' + type + ' span').text(message);
			$('#theme_report_' + type).css({'display': 'flex', 'opacity': 0});
			$('#theme_loading').hide();
			$('#theme_report_' + type).animate({'opacity': 1}, 250);
			theme_report_timeout = setTimeout(function()
			{
				$('#theme_report_' + type).animate({'opacity': 0}, 250, theme_report_hide);
			}, 2000);
		};

		$('#theme_options input[type="submit"]').prop('disabled', true);
		$('#theme_loading').show();

		$.post(
			gallery_path + '/ajax.php',
			{
				anticsrf: anticsrf,
				section: 'theme-params',
				template: 'default',
				params: theme_params_json
			},
			function(r)
			{
				if (typeof r != 'object' || r === null)
				{
					return;
				}
				switch (r.status)
				{
					case 'error' :
						message('error', r.message);
						break;

					case 'success' :
						message('success', r.message);
						break;
				}
			},
			'json'
		);

		return false;
	});

	// Bouton annuler.
	$('#theme_options form input[name="cancel"]').click(function()
	{
		$('#theme_options_icon a').click();
	});

	// Message de rapport.
	$('div[id^="theme_report"]').click(function()
	{
		clearTimeout(theme_report_timeout);
		theme_report_hide();
	});
});



/**
 * Diaporama.
 *
 */
jQuery(function($)
{
	if ($('#link_diaporama a').length)
	{
		var diaporama = new Diaporama(diaporama_query, diaporama_position, diaporama_options);

		$('#link_diaporama a').click(function()
		{
			diaporama.start();
		});
	}
});