<?php
declare(strict_types = 1);

// Paramètres en base de données.
$params = Template::$data['theme']['params'];

// Paramètres par défaut.
if (!is_array($params)
|| !isset($params['style']) || !isset($params['color'])
|| !isset($params['banner']) || !isset($params['background'])
|| !isset($params['buttons']) || !isset($params['css'])
|| !isset($params['thumbs_items']) || !isset($params['display']))
{
	$params =
	[
		'style' => 'clear',
		'color' =>
		[
			'clear' => '3B5EB5',
			'dark' => 'D54949'
		],
		'banner' =>
		[
			'clear' =>
			[
				'type' => 'texture',
				'texture' => 'diamond-upholstery.png',
				'file' => '',
				'height' => '120px'
			],
			'dark' =>
			[
				'type' => 'texture',
				'texture' => 'brushed-alum.png',
				'file' => '',
				'height' => '120px'
			]
		],
		'background' =>
		[
			'clear' =>
			[
				'type' => 'border',
				'fixed' => '1',
				'texture' => 'swirl-pattern.png'
			],
			'dark' =>
			[
				'type' => 'border',
				'fixed' => '1',
				'texture' => 'stardust.png'
			]
		],
		'buttons' =>
		[
			'clear' =>
			[
				'style' => '1'
			],
			'dark' =>
			[
				'style' => '1'
			]
		],
		'css' =>
		[
			'clear' => '',
			'dark' => ''
		],
		'thumbs_items' =>
		[
			'layout' => 'standard'
		],
		'display' =>
		[
			'item_pagination_bottom' => '1',
			'item_pagination_top' => '0',
			'item_prev_next' => '1',
			'item_properties' => '1',
			'item_stats' => '1',
			'item_title' => '1',
			'menu' => '1'
		]
	];
}

// Convertit la couleur au format RGB, afin de ne pas la confondre
// avec d'autres couleurs lors de modifications par Javascript.
$color = $params['color'][$params['style']];
$color = preg_match('`^[a-f\d]{6}$`i', $color) ? $color : 'B68D2A';
list($r, $g, $b) = sscanf($color, '%02x%02x%02x');
$color = "rgb($r, $g, $b)";

// Réduction du code CSS.
$css_minify = function($file) use (&$color, &$tpl)
{
	$css = file_get_contents(__DIR__ . '/../style/' . $file);

	// Suppression des commentaires.
	$css = preg_replace('`/\*[\s\S]*?\*/`', '', $css);

	// Suppression des sauts de ligne et des tabulations.
	$css = str_replace(["\n", "\r", "\t"], '', $css);

	// Réduction et suppression des espaces inutiles.
	$css = preg_replace('`\s+`', ' ', $css);
	$css = preg_replace('`([:,])\s`', '$1', $css);

	// Couleur.
	$css = preg_replace('`rgb\(\d+,\s*\d+,\s*\d+\)`i', $color, $css);

	return $css;
};

// Liste des textures disponibles.
$textures =
[
	'banner' =>
	[
		'clear' =>
		[
			'cubes.png' => '',
			'diamond-upholstery.png' => '',
			'dimension.png' => '',

			'foggy-birds.png' => '',
			'food.png' => '',
			'green-gobbler.png' => '',

			'light-wool.png' => '',
			'starring.png' => '',
			'tiny-grid.png' => ''
		],
		'dark' =>
		[
			'brushed-alum.png' => '#111',
			'climpek.png' => '#4c4c4c',
			'cubes.png' => '#4c4c4c',

			'diamond-upholstery.png' => '#3c3c3c',
			'dimension.png' => '#4c4c4c',
			'escheresque.png' => '#111',

			'foggy-birds.png' => '#4c4c4c',
			'light-wool.png' => '#4c4c4c',
			'subtle-stripes.png' => '#4c4c4c'
		]
	],
	'background' =>
	[
		'clear' =>
		[
			'arches.png' => '#fff',
			'batthern.png' => '#fff',
			'climpek.png' => '#fff',

			'dimension.png' => '#fff',
			'food.png' => '#fff',
			'hatches.png' => '#fff',

			'memphis-colorful.png' => '#fff',
			'swirl-pattern.png' => '#fff',
			'washi.png' => '#fff'
		],
		'dark' =>
		[
			'black-mamba.png' => '#111',
			'simple-dashed.png' => '#111',
			'stardust.png' => '#111'
		]
	]
];

// Répertoires.
$textures_dir = CONF_GALLERY_PATH . '/images/textures/';
$banners_dir = CONF_GALLERY_PATH . '/images/banners/';

// Données de template des options du thème.
if ($tpl['user']['admin'])
{
	// Paramètres du thème au format JSON.
	Template::set('theme', ['params_json' => Utility::jsonEncode($params)]);

	// Palette.
	Template::set('theme', ['palette' =>
	[
		'575757', '966B3C', '877240', '888040', '7F8840', '61893D', '3D8946',
		'828282', '977857', '877B5A', '9D933F', '8F9D3F', '76A64B', '5FA567',
		'3A8E67', '369291', '328296', '3B7AB5', '3B5EB5', '584EB5', '873D9F',
		'37A575', '2DAEB5', '159DC4', '6492D8', '738DE0', '7E6EB8', 'B577DD',
		'9D3DA6', 'B52262', 'E954A6', 'D22828', 'D85C18', 'CD842D', 'C89418',
		'D15CD9', 'D575BB', 'DE6CAC', 'D54949', 'D55949', 'D47149', 'C47E2C'
	]]);

	// Textures.
	Template::set('theme', ['textures_json' => Utility::jsonEncode($textures)]);
	Template::set('theme', ['textures_dir' => $textures_dir]);

	// Bannières.
	$banners = [];
	foreach (scandir(GALLERY_ROOT . '/images/banners') as $f)
	{
		if (preg_match('`^[a-z0-9_-]{1,250}\.(gif|jpe?g|png|webp)$`i', $f))
		{
			$banners[] = $f;
		}
	}
	Template::set('theme', ['banners' => $banners]);
	Template::set('theme', ['banners_dir' => $banners_dir]);
}

// CSS : couleur.
echo $css_minify('color.css');

// CSS : style sombre.
if ($params['style'] == 'dark')
{
	$css_dark = $css_minify('dark.css');
	echo $tpl['user']['admin'] ? '/*<dark>*/' . $css_dark . '/*</dark>*/' : $css_dark;
}
else if ($tpl['user']['admin'])
{
	echo '/*<dark>*//*' . $css_minify('dark.css') . '*//*</dark>*/';
}

// CSS : boutons de formulaires (style clair).
$start = $end = '';
if ($tpl['user']['admin'])
{
	$start = '/*<buttons_style_2_clear>*/';
	$end = '/*</buttons_style_2_clear>*/';
	if ($params['buttons'][$params['style']]['style'] != '2' || $params['style'] != 'clear')
	{
		$start = $start . '/*';
		$end = '*/' . $end;
	}
}
if ($tpl['user']['admin']
|| ($params['buttons'][$params['style']]['style'] == '2' && $params['style'] == 'clear'))
{
	$css = '.button,.button:active,.button:focus,.button:hover{'
		. 'background:%3$s;border:2px solid %3$s;padding:6px 12px;border-radius:20px;'
		. 'color:white;box-shadow:none;}.button:active,.button:focus,.button:hover'
		. '{color:%3$s;background:white;}.button:active{box-shadow:0 0 8px gray;}';
	printf('%1$s' . $css . '%2$s', $start, $end, $color);
}

// CSS : boutons de formulaires (style sombre).
$start = $end = '';
if ($tpl['user']['admin'])
{
	$start = '/*<buttons_style_2_dark>*/';
	$end = '/*</buttons_style_2_dark>*/';
	if ($params['buttons'][$params['style']]['style'] != '2' || $params['style'] != 'dark')
	{
		$start = $start . '/*';
		$end = '*/' . $end;
	}
}
if ($tpl['user']['admin']
|| ($params['buttons'][$params['style']]['style'] == '2' && $params['style'] == 'dark'))
{
	$css = '.button,.button:active,.button:focus,.button:hover{border-radius:20px;'
		. 'outline:none;}.button,.button:active.button:hover:active{padding:6px 12px;'
		. 'border:2px solid %3$s;}.button:focus,.button:hover{padding:8px 14px;border:0;}';
	printf('%1$s' . $css . '%2$s', $start, $end, $color);
}

// CSS pour écrans larges.
$css_large_screen = '';

// CSS : bannière, hauteur.
$start = $end = '';
if ($tpl['user']['admin'])
{
	$start = '/*<banner_height>*/';
	$end = '/*</banner_height>*/';
}
$css_large_screen .= sprintf(
	'%sheader.banner #header_top{height:%s}%s',
	$start, $params['banner'][$params['style']]['height'], $end
);

// CSS : bannière ?
$is_banner = $params['banner'][$params['style']]['type'] != 'none';

// CSS : bannière, texture.
$file = $params['banner'][$params['style']]['texture'];
$banner_color = $textures['banner'][$params['style']][$file];
if (!$banner_color)
{
	$banner_color = '#' . $params['color'][$params['style']];
}
$start = $end = '';
if ($tpl['user']['admin'])
{
	$start = '/*<banner_texture>*/';
	$end = '/*</banner_texture>*/';
	if ($params['banner'][$params['style']]['type'] != 'texture')
	{
		$start = $start . '/*';
		$end = '*/' . $end;
	}
}
if ($tpl['user']['admin'] || $params['banner'][$params['style']]['type'] == 'texture')
{
	$css_large_screen .= sprintf(
		'%sheader.banner #header_top{background:%s url(%s%s)}%s',
		$start, $banner_color, $textures_dir, $file, $end
	);
}

// CSS : bannière, fichier.
$start = $end = '';
if ($tpl['user']['admin'])
{
	$start = '/*<banner_file>*/';
	$end = '/*</banner_file>*/';
	if ($params['banner'][$params['style']]['type'] != 'file')
	{
		$start = $start . '/*';
		$end = '*/' . $end;
	}
}
if ($tpl['user']['admin'] || $params['banner'][$params['style']]['type'] == 'file')
{
	$file = $params['banner'][$params['style']]['file'] ?? '';
	$css_large_screen .= sprintf(
		'%sheader.banner #header_top{background-image:url(%s%s)}%s',
		$start, $banners_dir, $file, $end
	);
}

// CSS : fond ?
$is_background = $params['background'][$params['style']]['type'] != 'none';

// CSS : fond, texture.
$start = $end = '';
if ($tpl['user']['admin'])
{
	$start = '/*<background_texture>*/';
	$end = '/*</background_texture>*/';
	if ($params['background'][$params['style']]['type'] != 'texture')
	{
		$start = $start . '/*';
		$end = '*/' . $end;
	}
}
if ($tpl['user']['admin'] || $params['background'][$params['style']]['type'] == 'texture')
{
	$fixed = $params['background'][$params['style']]['fixed'] == 1 ? 'fixed' : '';
	$file = $params['background'][$params['style']]['texture'];
	$bg_color = $textures['background'][$params['style']][$file] ?? '';
	$css_large_screen .= sprintf(
		'%sbody.bg{background:%s %s url(%s%s)}%s',
		$start, $fixed, $bg_color, $textures_dir, $file, $end
	);
}

printf('@media(min-width:1180px){%s}', $css_large_screen);

// CSS : code personnalisé.
$css = preg_replace(
	'`(\{[\s\S]*?)#color([\s\S]*?\})`i', '$1' . $color . '$2',
	$params['css'][$params['style']]
);
$css = $tpl['user']['admin'] ? '/*<css_code>*/' . $css . '/*</css_code>*/' : $css;
echo $css;

// Type d'affichage des vignettes de fichiers.
$thumbs_items_layout = $params['thumbs_items']['layout'];

// Éléments à afficher.
foreach ($params['display'] as $k => $v)
{
	${'display_' . $k} = (bool) $params['display'][$k];
}
?>