<?php
declare(strict_types = 1);

/**
 * Création des vignettes.
 *
 * @license http://www.gnu.org/licenses/gpl.html
 * @link http://www.igalerie.org/
 */

// Paramètres GET utilisés.
$gets = ['crop', 'file', 'item', 'key', 'quality', 'size', 'type'];
$_GET['crop'] = $_GET['crop'] ?? '';

require_once(__DIR__ . '/includes/prepend.php');

// Vérification du format des paramètres.
if (!isset($_GET['file'])
 || !preg_match('`^[a-z]?\d{1,12}\-[a-f\d]{32}\.[a-z]{3,4}$`i', $_GET['file'])
 || !isset($_GET['item']) || !preg_match('`^(.{1,255})(\.[a-z0-9]{3,4})$`i', $_GET['item'], $item)
 || !isset($_GET['key']) || !preg_match('`^[a-f0-9]{32}$`', $_GET['key'])
 || !isset($_GET['quality']) || !preg_match('`^\d{1,3}$`', $_GET['quality'])
 || !isset($_GET['size']) || !preg_match('`^(\d{2,4})(?:x(\d{2,4}))?$`', $_GET['size'], $max_size)
 || !isset($_GET['type']) || !in_array($_GET['type'], ['cat', 'item', 'pending'])
 || !isset($_GET['crop']) || !preg_match('`^([\d,]{7,32})?$`', $_GET['crop']))
{
	die(App::httpResponse(400));
}

// Vérification de la clé de sécurité.
$key_params =
[
	$_GET['file'], $_GET['item'], $_GET['quality'], $_GET['size'], $_GET['type'], $_GET['crop']
];
if (!App::fileKeyVerify($key_params, $_GET['key']))
{
	die(App::httpResponse(403));
}

// Emplacement des fichiers.
if ($item[2] == '.vid')
{
	$file = GALLERY_ROOT . '/cache/captures/' . $item[1] . '.jpg';
}
else
{
	$file = $_GET['type'] == 'pending'
		? GALLERY_ROOT . '/pending/' . $_GET['item']
		: CONF_ALBUMS_PATH . '/' . $_GET['item'];
}
$file_thumb = GALLERY_ROOT . '/cache/thumbs/' . $_GET['file'];

// On crée la vignette si elle n'existe pas.
if (!file_exists($file_thumb))
{
	// On vérifie la présence de GD.
	if (!function_exists('imagetypes'))
	{
		die('GD is not activated.');
	}

	// On vérifie l'existence du fichier.
	if (!file_exists($file))
	{
		die('File does not exist.');
	}

	// Création de l'image GD.
	if (!$i = Image::getTypeSize($file))
	{
		die('Invalid image.');
	}
	$src_img = GD::createImage($file, $i['filetype']);
	if (is_string($src_img))
	{
		die($src_img);
	}
	if (is_bool($src_img))
	{
		die(sprintf('Cannot create image (%s).', $i['filetype']));
	}

	// Dimensions de la vignette.
	$max_width = (int) $max_size[1];
	$max_height = (int) ($max_size[2] ?? $max_size[1]);

	// Vignette personnalisée (rognage spécifique + redimensionnement).
	if ($_GET['crop'])
	{
		$crop = explode(',', $_GET['crop']);
		$crop =
		[
			'x' => (int) $crop[0],
			'y' => (int) $crop[1],
			'w' => (int) $crop[2],
			'h' => (int) $crop[3]
		];

		$src_coords = $crop;

		if (isset($max_size[2]))
		{
			$dst_size = ['w' => $max_width, 'h' => $max_height];
			$src_coords = Image::getCroppedSource(
				$crop['w'], $crop['h'], $dst_size['w'], $dst_size['h']
			);
			$src_coords['x'] += $crop['x'];
			$src_coords['y'] += $crop['y'];
		}
		else
		{
			$dst_size = Image::getResizedSize($crop['w'], $crop['h'], $max_width, $max_height);
		}
	}

	// Vignette rognée (rognage + redimensionnement).
	else if (isset($max_size[2]))
	{
		$dst_size = ['w' => $max_width, 'h' => $max_height];
		$src_coords = Image::getCroppedSource(
			$i['width'], $i['height'], $dst_size['w'], $dst_size['h']
		);
	}

	// Vignette standard (redimensionnement simple).
	else
	{
		$dst_size = Image::getResizedSize($i['width'], $i['height'], $max_width, $max_height);
	}

	$dst_img = GD::resize($src_img,
		$src_coords['x'] ?? 0, $src_coords['y'] ?? 0,
		$src_coords['w'] ?? $i['width'], $src_coords['h'] ?? $i['height'],
		0, 0,
		$dst_size['w'] ?? $i['width'], $dst_size['h'] ?? $i['height']
	);

	// Enregistrement de l'image GD.
	GD::file($dst_img, $file_thumb, $i['filetype'], (int) $_GET['quality']);
}

// Lecture du fichier.
Image::read($file_thumb);
?>